@@ -159,6 +159,18 @@ type QueryConfig struct {
 	// format is
 	// `projects/{project}/locations/{location}/reservations/{reservation}`.
 	Reservation string
+
+	// A target limit on the rate of slot consumption by this query. If set to a
+	// value > 0, BigQuery will attempt to limit the rate of slot consumption by
+	// this query to keep it below the configured limit, even if the query is
+	// eligible for more slots based on fair scheduling. The unused slots will be
+	// available for other jobs and queries to use.
+	//
+	// Note: This feature is not yet generally available.
+	MaxSlots int32
+
+	// Whether to run the query as continuous or a regular query.
+	Continuous bool
 }
 
 func (qc *QueryConfig) toBQ() (*bq.JobConfiguration, error) {
@@ -175,6 +187,7 @@ func (qc *QueryConfig) toBQ() (*bq.JobConfiguration, error) {
 		DestinationEncryptionConfiguration: qc.DestinationEncryptionConfig.toBQ(),
 		SchemaUpdateOptions:                qc.SchemaUpdateOptions,
 		CreateSession:                      qc.CreateSession,
+		Continuous:                         qc.Continuous,
 	}
 	if len(qc.TableDefinitions) > 0 {
 		qconf.TableDefinitions = make(map[string]bq.ExternalDataConfiguration)
@@ -234,6 +247,7 @@ func (qc *QueryConfig) toBQ() (*bq.JobConfiguration, error) {
 		Labels:      qc.Labels,
 		DryRun:      qc.DryRun,
 		Reservation: qc.Reservation,
+		MaxSlots:    int64(qc.MaxSlots),
 		Query:       qconf,
 	}
 	if qc.JobTimeout > 0 {
@@ -261,9 +275,11 @@ func bqToQueryConfig(q *bq.JobConfiguration, c *Client) (*QueryConfig, error) {
 		DestinationEncryptionConfig: bqToEncryptionConfig(qq.DestinationEncryptionConfiguration),
 		SchemaUpdateOptions:         qq.SchemaUpdateOptions,
 		CreateSession:               qq.CreateSession,
+		Continuous:                  qq.Continuous,
 	}
 	qc.UseStandardSQL = !qc.UseLegacySQL
 	qc.Reservation = q.Reservation
+	qc.MaxSlots = int32(q.MaxSlots)
 
 	if len(qq.TableDefinitions) > 0 {
 		qc.TableDefinitions = make(map[string]ExternalData)
@@ -467,6 +483,7 @@ func (q *Query) probeFastPath() (*bq.QueryRequest, error) {
 		q.QueryConfig.DestinationEncryptionConfig != nil ||
 		q.QueryConfig.SchemaUpdateOptions != nil ||
 		q.QueryConfig.JobTimeout != 0 ||
+		q.QueryConfig.Continuous ||
 		// User has defined the jobID generation behavior
 		q.JobIDConfig.JobID != "" {
 		return nil, fmt.Errorf("QueryConfig incompatible with fastPath")
@@ -480,9 +497,10 @@ func (q *Query) probeFastPath() (*bq.QueryRequest, error) {
 		MaximumBytesBilled: q.QueryConfig.MaxBytesBilled,
 		RequestId:          uid.NewSpace("request", nil).New(),
 		Reservation:        q.Reservation,
+		MaxSlots:           int64(q.MaxSlots),
 		Labels:             q.Labels,
 		FormatOptions: &bq.DataFormatOptions{
-			UseInt64Timestamp: true,
+			UseInt64Timestamp: defaultUseInt64Timestamp,
 		},
 	}
 	if q.QueryConfig.DisableQueryCache {
